library PL_Messagebox;

// Delphi 5 DLL-source (COUNTER.DLL)
// Defines a simple binary counter component for ProfiLab
// with adjustable number of output bits

uses
  SysUtils,
  Windows,
  Classes,
  Controls,
  Forms,
  Dlg_BoxConfig in 'Dlg_BoxConfig.pas' {BoxConfigDlg};

{$R *.RES}

Const  Inputs = 3;  // number of inputs
       Outputs = 2; // number of outputs

       {INPUTS}
       CLK   = 0;   // index of input variable CLK
       CAP   = 1;   // index of input variable CAP
       TXT   = 2;   // index of input variable TXT

       {OUTPUTS}
       RES   = 0;   // index of output variable RES
       CLKOUT= 1;   // index of output variable CLK

       {USER}
       CLK_old = 0;          // index of user variable CLK_old
       BoxStyle = 1;
       BoxIcon = 2;
       DLLIndex = 100;       // fixed index of DLL No. (set by ProfiLab)

Type TDLLParams = array[0..100] of extended;   //Type of ProfiLab DLL parameters
     PDLLParams = ^TDLLParams;                 // Pointer to ProfiLab DLL parameters

type TStringParams = array[0..100] of PChar;
     PStringParams = ^TStringParams;


function NumInputs: Byte;
begin
  result:=Inputs; //Define FIXED number of component input pins
end;

function NumOutputs: Byte; // Made adjustable with 'NumOutputsEx'
begin
  result:=Outputs; //Define FIXED number of component output pins
end;

Function InputName(Channel: Byte): ShortString; // Return name for each component input pin
begin
   case Channel of
   CLK: result:='|CLK';   //  "CLK" (Clock)
   CAP: result:='$CAP';  //  "$CAP" (Caption)
   TXT: result:='$TXT';  //  "$TXT" (Message text)
   end;
end;

Function OutputName(Channel: Byte): ShortString; // Return name for each component output pin
begin
   case Channel of
   RES: result:='RES';       //  "RES" (Box result as defined by windows)
   CLKOUT: result:='CLK';    //  "CLK" (Clock out)
   end;
end;

Procedure SimStart(PInput,POutput,PUser: PDLLParams); //called when ProfiLab enters RUN mode
begin
  POutput^[RES]:=0;                      // Result = 0
  POutput^[CLKOUT]:=5;                   // CLKOUT = high
  PUser^[CLK_old]:=0;                    // avoid trigger on project start
end;

Procedure SimStop(PInput,POutput,PUser: PDLLParams); //called when ProfiLab RUN mode is terminated
begin
  // nothing to be done
end;

Procedure CalculateEx(PInput,POutput,PUser: PDLLParams; PStrings: PStringParams);
var mbParams: DWord;
begin
   if PInput^[CLK]<2.5 then //check CLK input LOW
   begin
      POutput^[CLKOUT]:=5; // Set CLOCKOUT high
      if (PInput^[CLK]<2.5) and not(PUser^[CLK_old]<2.5) then //check out falling edge at CLK input
      begin
         mbParams:=0;
         case round(PUser^[BoxStyle]) of
         0: mbParams:=mbParams or MB_ABORTRETRYIGNORE;
         1: mbParams:=mbParams or MB_OK;
         2: mbParams:=mbParams or MB_OKCANCEL;
         3: mbParams:=mbParams or MB_RETRYCANCEL;
         4: mbParams:=mbParams or MB_YESNO;
         5: mbParams:=mbParams or MB_YESNOCANCEL;
         end;
         case round(PUser^[BoxIcon]) of
         1: mbParams:=mbParams or MB_ICONEXCLAMATION;
         2: mbParams:=mbParams or MB_ICONWARNING;
         3: mbParams:=mbParams or MB_ICONINFORMATION;
         4: mbParams:=mbParams or MB_ICONASTERISK;
         5: mbParams:=mbParams or MB_ICONQUESTION;
         6: mbParams:=mbParams or MB_ICONSTOP;
         7: mbParams:=mbParams or MB_ICONERROR;
         8: mbParams:=mbParams or MB_ICONHAND;
         end;
         // Do mesagebox and get result
         POutput^[RES]:=messagebox(FindWindow('TFrontplatte',nil),PChar(PStrings^[TXT]),PChar(PStrings^[CAP]), mbParams);
         POutput^[CLKOUT]:=0; //CLKOUT low ; falling edge indactes box is done
      end;
   end;
   PUser^[CLK_old]:=PInput^[CLK]; //Remember CLK status for next call
end;

Procedure Configure(PUser: PDLLParams);
var DLG: TBoxConfigDlg;
begin

   DLG:=TBoxConfigDlg.Create(nil);                       //Create user dialogue
   With DLG do
   begin
      Caption:='Messagebox [DLL'+FloatToStr(PUser^[DLLIndex])+']'; // Show ProfiLab DLL-Index in dialogue caption

      cbStyle.itemindex:=round(PUser^[BoxStyle]);
      cbIcon.itemindex:=round(PUser^[BoxIcon]);

      if ShowModal=mrOK then                                 // Execute dialogue
      begin
         PUser^[BoxStyle]:=cbStyle.itemindex;
         PUser^[BoxIcon]:=cbIcon.itemindex;
      end;

      free;                                                  // Dont forget to free dialogue
   end;
end;


//export methods for ProfiLab
exports SimStart,
        SimStop,
        NumInputs,
        NumOutputs,
        CalculateEx,
        InputName,
        OutputName,
        Configure;
begin
end.

